import mira.tools as tl
import mira.topic_model as topics
import mira.pseudotime as time
import mira.adata_interface.utils as utils
import mira.preferences as pref
import mira.rp_model as rp
import mira.plots as pl
from mira import datasets as datasets

__version__ = "1.0.0"

import logging
logging.basicConfig(level= logging.INFO)